#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-09 09:53:18.676780

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class LicenseSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         LicenseSettingAtt
                | 
                | Interface to handle the licensing settings.
                | Role: This interface is implemented by a component which represents the
                | controller of the static Licenses.
                | To access this property page:
                | Click the Options command in the Tools menu
                | Click General
                | Click the Licensing Property Page
                | 
                | This interface defines:
                | A method to set each License
                | A method to get the value of each License
                | A method to lock/unlock each parameter
                | A method to retrieve the information concerning each parameter
    
    """

    def __init__(self, setting_controller):
        super().__init__(setting_controller.com_object)
        self.license_setting_att = setting_controller.com_object

    @property
    def demo_mode(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property DemoMode() As boolean
                | 
                |     Retrieves or Sets the demo mode.
                |     Role: Retrieves or sets the value of the parameter describing if the demo
                |     mode is active.

        :return: bool
        """

        return self.license_setting_att.DemoMode

    @demo_mode.setter
    def demo_mode(self, value):
        """
        :param bool value:
        """

        self.license_setting_att.DemoMode = value

    @property
    def frequency(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property Frequency() As float
                | 
                |     Retrieves or Sets the contact frequency.
                |     Role: Retrieves or sets the value of the parameter describing the server
                |     contact frequency in minutes. Note that a null value represents the maximum
                |     contact frequency value. For more information about the range and maximum,
                |     refers to the Infrastructure documentation.

        :return: float
        """

        return self.license_setting_att.Frequency

    @frequency.setter
    def frequency(self, value):
        """
        :param float value:
        """

        self.license_setting_att.Frequency = value

    @property
    def nodelock_alert(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property NodelockAlert() As long
                | 
                |     Retrieves or Sets the license expiry alert.
                |     Role: Retrieves or sets the value of the parameter describing the lthe
                |     license expiry alertt in days. For more information about the range and
                |     maximum, refers to the Infrastructure documentation.

        :return: int
        """

        return self.license_setting_att.NodelockAlert

    @nodelock_alert.setter
    def nodelock_alert(self, value):
        """
        :param int value:
        """

        self.license_setting_att.NodelockAlert = value

    @property
    def server_time_out(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property ServerTimeOut() As float
                | 
                |     Retrieves or Sets the server time out.
                |     Role: Retrieves or sets the value of the parameter describing the licensing
                |     server time out in minutes. For more information about the range and maximum,
                |     refers to the Infrastructure documentation.

        :return: float
        """

        return self.license_setting_att.ServerTimeOut

    @server_time_out.setter
    def server_time_out(self, value):
        """
        :param float value:
        """

        self.license_setting_att.ServerTimeOut = value

    @property
    def show_license(self):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780)
                | o Property ShowLicense() As boolean
                | 
                |     Retrieves or Sets the show license .
                |     Role: Retrieves or sets the value of the parameter describing the complete
                |     license information. When the parameter is set, the user gets more information
                |     about the reason of the failure to request a license.

        :return: bool
        """

        return self.license_setting_att.ShowLicense

    @show_license.setter
    def show_license(self, value):
        """
        :param bool value:
        """

        self.license_setting_att.ShowLicense = value

    def get_demo_mode_info(self, io_admin_level, io_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetDemoModeInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the DemoMode setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: None
        """
        return self.license_setting_att.GetDemoModeInfo(io_admin_level, io_locked)

    def get_frequency_info(self, io_admin_level, io_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetFrequencyInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the Frequency setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: None
        """
        return self.license_setting_att.GetFrequencyInfo(io_admin_level, io_locked)

    def get_granted_licenses_list(self, i_default_licenses):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetGrantedLicensesList(long iDefaultLicenses) As
                | CATSafeArrayVariant
                | 
                |     Deprecated:
                |         V5R15 CATSysLicenseSettingAtt#GetLicensesList

        :param int i_default_licenses:
        :return: tuple
        """
        return tuple(self.license_setting_att.GetGrantedLicensesList(i_default_licenses))

    def get_license(self, i_license):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetLicense(CATBSTR iLicense) As CATBSTR
                | 
                |     Retrieves the value of the license.
                |     Role: Retrieves the mapping between a name of a license and the value of
                |     the license. The license does not need to be returned by GetLicensesList(). But
                |     if the license is not installed the license will be
                |     "NotRequested"
                | 
                |     Parameters:
                | 
                |         iLicense
                |             the name of the License: "PMG.prd", "_MD2.slt+", "_MD2.slt+GSD" for
                |             example.
                |             "PMG.prd" represent the license of the product
                |             PMG.
                |             "_MD2.slt+" represent the license of the solution
                |             MD2.
                |             "_MD2.slt+GSD" represent the license of the solution MD2, with the
                |             AddOn product GSD. 
                | 
                |     Returns:
                |         the value of the License:
                |         NotRequested : License is not Requested
                |         key : the name of the license, the default available license has been chosen by the user.
                |               License is Requested.
                |         License Number : a specific license number has been chosen by the user. License is Requested.

        :param str i_license:
        :return: str
        """
        return str(self.license_setting_att.GetLicense(i_license))

    def get_license_info(self, i_license, io_admin_level, io_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetLicenseInfo(CATBSTR iLicense,
                | CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the License setting parameter.
                |     Refer to SettingController for a detailed description.

        :param str i_license:
        :param str io_admin_level:
        :param str io_locked:
        :return: None
        """
        return self.license_setting_att.GetLicenseInfo(i_license, io_admin_level, io_locked)

    def get_licenses_list(self, i_default_licenses):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetLicensesList(long iDefaultLicenses) As
                | CATSafeArrayVariant
                | 
                |     Retrieves the list of the requested or locked licenses.
                |     Role: Retrieves the list of the requested or locked licenses. There is no
                |     SetLicensesList() because the list is initialized using
                |     LUM.
                | 
                |     Parameters:
                | 
                |         iDefaultLicenses
                |             If iDefaultLicenses!=0 and the settings are empty, returns the
                |             default licenses, that is, the visible nodolocked licenses. If iDefaultLicenses
                |             == 0 and the settings are empty, returns the selected licenses (not yet stored,
                |             because not yet validated by OK button). 
                | 
                |     Returns:
                |         The array of Licenses.
                |         character meaning in license name:
                |         "_": internal notation for a license configuration
                |         "+": you chose "Any license" mode, example of returned value:
                |         _ME1.slt+FS1
                |         When the return value is a serial number (_ME1.slt_SerialNumber), you
                |         have chosen the "Explicit" license mode. In this case the add on product is not
                |         indicated in the license name.

        :param int i_default_licenses:
        :return: tuple
        """
        return tuple(self.license_setting_att.GetLicensesList(i_default_licenses))

    def get_licenses_list_info(self, io_admin_level, io_lock):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetLicensesListInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLock) As boolean
                | 
                |     Retrieves information about the LicensesList setting
                |     parameter.
                |     Role: Retrieves information about the LicensesList setting locking state
                |     (global lock for the LicensesList). It is used to get the lock status of the
                |     List of the Licenses. If the LicensesList is locked all the licenses are
                |     locked. When the licenses are locked, it means that an administrator has locked
                |     the attribute. It does not means that an administrator has changed the value of
                |     the attribute. The value of the setting is not updatable because it refers to a
                |     lock on a list. That is why the return value is false.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel:
                |             Level of administrator. 
                |         ioLock:
                |             Locked/Unlocked. 
                | 
                |     Returns:
                |         False
                |         Information returned in the dump:
                |         Parameter 1 : "Value taken in case of reset" : useless. Default value : "Default value"
                |         Parameter 2 : "Locking state" value : unlocked / locked / locked at Admin Level n
                |         Parameter 3 : "Returned value" : useless, default value : False
                | 
                |         Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_lock:
        :return: None
        """
        return self.license_setting_att.GetLicensesListInfo(io_admin_level, io_lock)

    def get_nodelock_alert_info(self, io_admin_level, io_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetNodelockAlertInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the license expiry alert setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: None
        """
        return self.license_setting_att.GetNodelockAlertInfo(io_admin_level, io_locked)

    def get_server_time_out_info(self, io_admin_level, io_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetServerTimeOutInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the TimeOut setting parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: None
        """
        return self.license_setting_att.GetServerTimeOutInfo(io_admin_level, io_locked)

    def get_show_license_info(self, io_admin_level, io_locked):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Func GetShowLicenseInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves information about the ShowLicense setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str io_admin_level:
        :param str io_locked:
        :return: None
        """
        return self.license_setting_att.GetShowLicenseInfo(io_admin_level, io_locked)

    def set_demo_mode_lock(self, i_lock):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetDemoModeLock(boolean iLock)
                | 
                |     Locks or unlocks the DemoMode setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :return: None
        """
        return self.license_setting_att.SetDemoModeLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_demo_mode_lock'
        # # vba_code = """
        # # Public Function set_demo_mode_lock(license_setting_att)
        # #     Dim iLock (2)
        # #     license_setting_att.SetDemoModeLock iLock
        # #     set_demo_mode_lock = iLock
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_frequency_lock(self, i_lock):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetFrequencyLock(boolean iLock)
                | 
                |     Locks or unlocks the Frequency setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :return: None
        """
        return self.license_setting_att.SetFrequencyLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_frequency_lock'
        # # vba_code = """
        # # Public Function set_frequency_lock(license_setting_att)
        # #     Dim iLock (2)
        # #     license_setting_att.SetFrequencyLock iLock
        # #     set_frequency_lock = iLock
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_license(self, i_license, i_value):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetLicense(CATBSTR iLicense,
                | CATBSTR iValue)
                | 
                |     Sets the License.
                |     Role: Sets the value of the license.
                | 
                |     Parameters:
                | 
                |         iLicense
                |             the name of the License: "PMG.prd", "_MD2.slt+", "_MD2.slt+GSD" for
                |             example.
                |             "PMG.prd" represent the license of the product
                |             PMG.
                |             "_MD2.slt+" represent the license of the solution
                |             MD2.
                |             "_MD2.slt+GSD" represent the license of the solution MD2, with the
                |             AddOn product GSD. 
                |         iValue
                | 
                |             the value of the License:
                |             NotRequested : License is not Requested
                |             key : the name of the license, the default available license has been chosen by the user.
                |                   License is Requested.
                |             License Number : a specific license number has been chosen by the user.
                |                              License is Requested.

        :param str i_license:
        :param str i_value:
        :return: None
        """
        return self.license_setting_att.SetLicense(i_license, i_value)

    def set_license_lock(self, i_license, i_lock):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetLicenseLock(CATBSTR iLicense,
                | boolean iLock)
                | 
                |     Locks or unlocks the License setting parameter.
                |     Refer to SettingController for a detailed description.

        :param str i_license:
        :param bool i_lock:
        :return: None
        """
        return self.license_setting_att.SetLicenseLock(i_license, i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_license_lock'
        # # vba_code = """
        # # Public Function set_license_lock(license_setting_att)
        # #     Dim iLicense (2)
        # #     license_setting_att.SetLicenseLock iLicense
        # #     set_license_lock = iLicense
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_licenses_list_lock(self, i_lock):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetLicensesListLock(boolean iLock)
                | 
                |     Locks or unlocks the LicensesList setting parameter.
                |     Role:Locks or unlocks the LicensesList setting parameter. Locks or unlocks
                |     the parameter describing the list of installed licenses, if the operation is
                |     allowed in the current administrated environment. It is the global lock on all
                |     the licenses. When the LicenseList is locked all the licenses are locked. When
                |     the LicenseList is unlocked all the licenses are unlocked.
                | 
                |     Parameters:
                | 
                |         iLock
                |             the locking operation to be performed:
                |             True: to lock the parameter.
                |             False: to unlock the parameter.
                |             Refer to 
                | 
                |         SettingController for a detailed description.

        :param bool i_lock:
        :return: None
        """
        return self.license_setting_att.SetLicensesListLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_licenses_list_lock'
        # # vba_code = """
        # # Public Function set_licenses_list_lock(license_setting_att)
        # #     Dim iLock (2)
        # #     license_setting_att.SetLicensesListLock iLock
        # #     set_licenses_list_lock = iLock
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_nodelock_alert_lock(self, i_lock):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetNodelockAlertLock(boolean iLock)
                | 
                |     Locks or unlocks the license expiry alert setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :return: None
        """
        return self.license_setting_att.SetNodelockAlertLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_nodelock_alert_lock'
        # # vba_code = """
        # # Public Function set_nodelock_alert_lock(license_setting_att)
        # #     Dim iLock (2)
        # #     license_setting_att.SetNodelockAlertLock iLock
        # #     set_nodelock_alert_lock = iLock
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_server_time_out_lock(self, i_lock):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetServerTimeOutLock(boolean iLock)
                | 
                |     Locks or unlocks the TimeOut setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :return: None
        """
        return self.license_setting_att.SetServerTimeOutLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_server_time_out_lock'
        # # vba_code = """
        # # Public Function set_server_time_out_lock(license_setting_att)
        # #     Dim iLock (2)
        # #     license_setting_att.SetServerTimeOutLock iLock
        # #     set_server_time_out_lock = iLock
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_show_license_lock(self, i_lock):
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-09 09:53:18.676780))
                | o Sub SetShowLicenseLock(boolean iLock)
                | 
                |     Locks or unlocks the ShowLicense setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :return: None
        """
        return self.license_setting_att.SetShowLicenseLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_show_license_lock'
        # # vba_code = """
        # # Public Function set_show_license_lock(license_setting_att)
        # #     Dim iLock (2)
        # #     license_setting_att.SetShowLicenseLock iLock
        # #     set_show_license_lock = iLock
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'LicenseSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_step import ABQStep
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQSteps(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQSteps
                | 
                | The collection of Abaqus analysis step (ABQStep) objects contained in
                | an
                | ABQAnalysisCase object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ABQStep)
        self.abq_steps = com_object

    def add(self, i_step_type: str) -> ABQStep:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(CATBSTR iStepType) As ABQStep
                | 
                |     Creates a new Abaqus Step and adds it to the collection of Abaqus
                |     steps.
                | 
                |     Parameters:
                | 
                |         iStepType
                |             The type of the step to create.
                | 
                |             Legal values: "ABQGeneralStaticStep", "ABQFrequencyStep",
                |             "ABQExplicitDynamicsStep", "ABQHeatTransferStep" "ABQLinearDynamicStepModal"
                |             "ABQLinearDynamicStepSubspace" 
                | 
                |     Returns:
                |         oStep The Abaqus step object that was created. 
                |     Example:
                |         The following example creates a general static step in the ABQSteps
                |         collection:
                | 
                |          Dim abqCase As ABQAnalysisCase
                |          Dim abaqusSteps As ABQSteps
                |          Dim generalstaticstep As ABQGeneralStaticStep
                |          Set abaqusSteps = abqCase.Steps
                |          Set generalstaticstep =  abaqusSteps.Add("ABQGeneralStaticStep")

        :param str i_step_type:
        :rtype: ABQStep
        """
        return ABQStep(self.abq_steps.Add(i_step_type))

    def insert(self, i_step_type: str, i_index: cat_variant) -> ABQStep:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Insert(CATBSTR iStepType,
                | CATVariant iIndex) As ABQStep
                | 
                |     Creates a new Abaqus Step and inserts it to the collection of Abaqus
                |     steps.
                | 
                |     Parameters:
                | 
                |         iStepType
                |             The type of the step to create.
                | 
                |             Legal values: "ABQGeneralStaticStep", "ABQFrequencyStep",
                |             "ABQExplicitDynamicsStep", "ABQHeatTransferStep" 
                |         iIndex
                |             Index of Abaqus step after which the new step is to be inserted.
                |             for initialization step iIndex is 1
                | 
                |     Returns:
                |         oStep The Abaqus step object that was inserted. 
                |     Example:
                |         The following example creates a general static step in the ABQSteps
                |         collection:
                | 
                |          Dim abqCase As ABQAnalysisCase
                |          Dim abaqusSteps As ABQSteps
                |          Dim generalstaticstep As ABQGeneralStaticStep
                |          Set abaqusSteps = abqCase.Steps
                |          Set generalstaticstep =  abaqusSteps.Insert("ABQGeneralStaticStep", 1)

        :param str i_step_type:
        :param cat_variant i_index:
        :rtype: ABQStep
        """
        return ABQStep(self.abq_steps.Insert(i_step_type, i_index))

    def item(self, i_index: cat_variant) -> ABQStep:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ABQStep
                | 
                |     Returns an Abaqus step using its index or its name from the ABQSteps
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus step to retrieve from the
                |             collection of Abaqus steps. If the index is a number, it specifies the rank of
                |             the Abaqus step in the collection. The index of the first Abaqus step in the
                |             collection is 1, and the index of the last step is Count. If the index is a
                |             string, it specifies the name you assigned to the step using the
                |             CATIACollection::Name property. 
                | 
                |     Returns:
                |         The specified ABQStep. 
                |     Example:
                |         This example retrieves the fifth Abaqus step in the collection and
                |         saves it in a variable called FirstStep. The example also retrieves the Abaqus
                |         step named "MyStep" in the collection and saves it in a variable called
                |         SecondStep.
                | 
                |          Set CaseColl = AnalysisDoc.ABQAnalysisModel.Cases
                |          Set ThisCase = CaseColl.Item(5)
                |          Set StepColl = ThisCase.Steps
                |          Set FirstStaticStep = StepColl.Item(5)
                |          Set SecondStaticStep = StepColl.Item("MyStep")

        :param cat_variant i_index:
        :rtype: ABQStep
        """
        return ABQStep(self.abq_steps.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an Abaqus step using its index or its name from the Step
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus step to retrieve from the
                |             collection of Abaqus Steps. If the index is a number, it specifies the rank of
                |             the Abaqus step in the collection. The index of the first Abaqus step in the
                |             collection is 1, and the index of the last step is Count. If the index is a
                |             string, it specifies the name you assigned to the step using the
                |             CATIABase::Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.abq_steps.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_steps)
        # #     Dim iIndex (2)
        # #     abq_steps.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQSteps(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_str_functional_interfaces.sfm_weld import SFMWeld
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class SFMWelds(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     SfmWelds
                | 
                | Interface to manage the Structure Functional Modeler Weld object's
                | collection.
                | Role: Provides access to Weld objects as a collection.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=SFMWeld)
        self.sfm_welds = com_object

    def item(self, i_index: cat_variant) -> SFMWeld:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As SfmWeld
                | 
                |     Gets Weld Feature.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             [in] Index of the Weld Feature to be retrieved. 
                |         oSfmWeld
                |             [out] The retrieved Weld Feature. 
                | 
                |     Returns:
                |         S_OK if everything ran ok
                | 
                |         Example:
                |             This example gets Weld Feature.
                | 
                |              Dim Welds As SfmWelds
                |              Set Welds = Split_Plate.GetWelds(Nothing)
                |              Dim j As Integer
                |              For j = 1 To Welds.Count
                |              Dim EachWeld As SfmWeld
                |              Set EachWeld = Welds.Item(j)
                |              Next

        :param cat_variant i_index:
        :rtype: SFMWeld
        """
        return SFMWeld(self.sfm_welds.Item(i_index))

    def __repr__(self):
        return f'SFMWelds(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_circle import HybridShapeCircle
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.length import Length


class HybridShapeCircle2PointsRad(HybridShapeCircle):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         CATGSMIDLItf.HybridShapeCircle
                |                             HybridShapeCircle2PointsRad
                | 
                | Represents the hybrid shape circle object defined using two points and a
                | radius.
                | Role: To access the data of the hybrid shape circle object.
                | 
                | This data includes:
                | 
                |     The circle two passing points
                |     The circle radius
                |     The surface that supports the circle
                |     The circle orientation
                | 
                | Use the CATIAHybridShapeFactory to create a HybridShapeCircle2PointsRad
                | object.
                | 
                | See also:
                |     HybridShapeFactory
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_circle2_points_rad = com_object

    @property
    def diameter(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Diameter() As Length (Read Only)
                | 
                |     Returns the circle diameter. It is expressed as a Length literal. Succeeds
                |     only if DiameterMode is set to True. 
                | 
                | Example:
                |     This example retrieves in HybShpCircleDiameter the diameter of the
                |     HybShpCircle hybrid shape circle feature
                | 
                |      Dim HybShpCircleDiameter As Length
                |      HybShpCircleDiameter = HybShpCircle.Diameter

        :rtype: Length
        """

        return Length(self.hybrid_shape_circle2_points_rad.Diameter)

    @property
    def diameter_mode(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property DiameterMode() As boolean
                | 
                |     Returns or sets the DiameterMode.
                |     Legal values: True implies diameter False implies radius (default). When
                |     DiameterMode is changed, Radius/Diameter value, which is stored will not be
                |     modified.
                | 
                |     Example:
                | 
                |            This example sets that the DiameterMode of
                |           the HybShpCircle hybrid shape circle feature
                |           
                | 
                |           HybShpCircle.DiameterMode = True

        :rtype: bool
        """

        return self.hybrid_shape_circle2_points_rad.DiameterMode

    @diameter_mode.setter
    def diameter_mode(self, value: bool):
        """
        :param bool value:
        """

        self.hybrid_shape_circle2_points_rad.DiameterMode = value

    @property
    def orientation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Orientation() As long
                | 
                |     Returns or sets the circle orientation.
                |     Role: The circle orientation indicates which side of the line made up using
                |     the two passing points is used to create the major part of the circle. It is
                |     determined using the cross product of the normal to the suppport and the vector
                |     made up using the two passing points (Pt1-Pt2).
                |     Legal values: 1 to state that the major part of the circle is or should be
                |     created on the side of the line shown by the vector resulting from this cross
                |     product, and -1 otherwise.
                | 
                |     Example:
                |         This example retrieves in HybShpCircleOrientation the orientation of
                |         the HybShpCircle hybrid shape circle.
                | 
                |          HybShpCircleOrientation = HybShpCircle.Orientation

        :rtype: int
        """

        return self.hybrid_shape_circle2_points_rad.Orientation

    @orientation.setter
    def orientation(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_circle2_points_rad.Orientation = value

    @property
    def pt1(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Pt1() As Reference
                | 
                |     Returns or sets the circle first passing point.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example:
                |         This example retrieves the first passing point of the HybShpCircle
                |         hybrid shape circle in HybShpCircleFirstPassingPoint
                |         point.
                | 
                |          Dim HybShpCircleFirstPassingPoint As Reference
                |          Set HybShpCircleFirstPassingPoint = HybShpCircle.Pt1

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_circle2_points_rad.Pt1)

    @pt1.setter
    def pt1(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_circle2_points_rad.Pt1 = reference_point.com_object

    @property
    def pt2(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Pt2() As Reference
                | 
                |     Returns or sets the circle second passing point.
                |     Sub-element(s) supported (see Boundary object): Vertex.
                | 
                |     Example:
                |         This example sets the second passing point of the HybShpCircle hybrid
                |         shape circle as the Point12 point.
                | 
                |          HybShpCircle.Pt2 Point12

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_circle2_points_rad.Pt2)

    @pt2.setter
    def pt2(self, reference_point: Reference):
        """
        :param Reference reference_point:
        """

        self.hybrid_shape_circle2_points_rad.Pt2 = reference_point.com_object

    @property
    def radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Radius() As Length (Read Only)
                | 
                |     Returns the circle radius.
                | 
                |     Parameters:
                | 
                |         Radius
                |             The circle radius, expressed as a 
                | 
                |         Length literal. Succeeds only if DiameterMode is set to False.
                |         
                | 
                | Example:
                |     This example retrieves in HybShpCircleRadius the radius of the HybShpCircle
                |     hybrid shape circle.
                | 
                |      Dim HybShpCircleRadius As Length
                |      HybShpCircleRadius = HybShpCircle.Radius

        :rtype: Length
        """

        return Length(self.hybrid_shape_circle2_points_rad.Radius)

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     Returns or sets the circle support surface.
                |     Sub-element(s) supported (see Boundary object): Face.
                | 
                |     Example:
                |         This example retrieves in HybShpCircleSupportSurf the support surface
                |         of the HybShpCircle hybrid shape circle.
                | 
                |          Dim HybShpCircleSupportSurf As Reference 
                |          HybShpCircleSupportSurf = HybShpCircle.Support

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_circle2_points_rad.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_circle2_points_rad.Support = reference_support

    def is_geodesic(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func IsGeodesic() As boolean
                | 
                |     Queries whether the circle is geodesic or not.
                | 
                |     Parameters:
                | 
                |         oGeod
                |             geodesic type : when TRUE, the circle is geodesic.

        :rtype: bool
        """
        return self.hybrid_shape_circle2_points_rad.IsGeodesic()

    def set_geometry_on_support(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub SetGeometryOnSupport()
                | 
                |     Sets GeometryOnSupport of circle.
                |     It puts the circle on the surface. S_OK if OK, E_FAIL if fail

        :rtype: None
        """
        return self.hybrid_shape_circle2_points_rad.SetGeometryOnSupport()

    def unset_geometry_on_support(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub UnsetGeometryOnSupport()
                | 
                |     Inactivates GeometryOnSupport of circle.
                |     Note: The circle becomes euclidean.

        :rtype: None
        """
        return self.hybrid_shape_circle2_points_rad.UnsetGeometryOnSupport()

    def __repr__(self):
        return f'HybridShapeCircle2PointsRad(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.abq_automation_interfaces.abq_output_request import ABQOutputRequest
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ABQOutputRequests(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ABQOutputRequests
                | 
                | The collection of Abaqus output request (ABQOutputRequest) objects attached to
                | an
                | ABQGeneralStaticStep, an ABQFrequencyStep, ABQHeatTransferStep, or an
                | ABQExplicitDynamicsStep object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ABQOutputRequest)
        self.abq_output_requests = com_object

    def add(self, i_output_request_type: int) -> ABQOutputRequest:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(ABQOutputRequestType iOutputRequestType) As
                | ABQOutputRequest
                | 
                |     Creates a new Abaqus output request and adds it to the collection of Abaqus
                |     output requests.
                | 
                |     Parameters:
                | 
                |         iOutputRequestType
                |             The type of the output request to create.
                | 
                |             Legal values:
                | 
                |             "ABQFIELD"
                |             "ABQHISTORY"
                |             "ABQDATA
                | 
                |     Returns:
                |         oOutputRequest The Abaqus output request object that was created.
                |         
                |     Example:
                |         The following example creates a field output request in the
                |         ABQOutputRequests collection:
                | 
                |          Dim abaqusOutputRequests As ABQOutputRequests
                |          Set abaqusOutputRequests = generalstaticstep.GetItem ("ABQVBOutputRequests")
                |          Dim abqFieldOutputRequest As ABQFieldOutputRequest
                |          Set abqFieldOutputRequest =  abaqusOutputRequests.Add("ABQFIELD")

        :param int i_output_request_type: enum abq_output_request_type
        :rtype: ABQOutputRequest
        """
        return ABQOutputRequest(self.abq_output_requests.Add(i_output_request_type))

    def item(self, i_index: cat_variant, i_output_request_type: int) -> ABQOutputRequest:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex,
                | ABQOutputRequestType iOutputRequestType) As ABQOutputRequest
                | 
                |     Returns an Abaqus output request using its index or its name and output
                |     request type from the ABQOutputRequests collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus output request to retrieve from
                |             the collection of Abaqus output requests. 
                |         iOutputRequestType
                |             The type of the output request.
                | 
                |             Legal values:
                | 
                |             "ABQFIELD"
                |             "ABQHISTORY"
                |             "ABQDATA
                | 
                |             If the index is a number, it specifies the rank of the Abaqus
                |             output request corresponding to the specified output request type in the
                |             collection. The index of the first Abaqus output request in the collection is 1
                |             and the index of the last output request is Count. If the index is a string, it
                |             specifies the name you assigned to the output request using the
                |             CATIACollection::Name property. 
                | 
                |     Returns:
                |         The specified ABQOutputRequest.

        :param cat_variant i_index:
        :param int i_output_request_type: enum abq_output_request_type
        :rtype: ABQOutputRequest
        """
        return ABQOutputRequest(self.abq_output_requests.Item(i_index, i_output_request_type))

    def remove(self, i_index: cat_variant, i_output_request_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex,
                | ABQOutputRequestType iOutputRequestType)
                | 
                |     Removes a Abaqus output request using its index or its name and output
                |     request type from the collection output requests.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the Abaqus output request to retrieve from
                |             the collection of Abaqus output requests. 
                |         iOutputRequestType
                |             The type of the output request.
                | 
                |             Legal values:
                | 
                |             "ABQFIELD"
                |             "ABQHISTORY"
                |             "ABQDATA
                | 
                |             If the index is a number, it specifies the rank of the Abaqus
                |             output request corresponding to the specified output request type in the
                |             collection. The index of the first Abaqus output request in the collection is 1
                |             and the index of the last output request is Count. If the index is a string, it
                |             specifies the name you assigned to the output request using the
                |             CATIACollection::Name property.

        :param cat_variant i_index:
        :param int i_output_request_type: enum abq_output_request_type
        :rtype: None
        """
        return self.abq_output_requests.Remove(i_index, i_output_request_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(abq_output_requests)
        # #     Dim iIndex (2)
        # #     abq_output_requests.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ABQOutputRequests(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class ToleranceSheetSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         ToleranceSheetSettingAtt
                | 
                | The interface to access a CATIAToleranceSheetSettingAtt.
                | This interface may be used to read or modify in the CATIA/Tools/Option the
                | settings values of Tolerance sheet.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.tolerance_sheet_setting_att = com_object

    @property
    def angle_max_tolerance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property AngleMaxTolerance() As double
                | 
                |     Returns or sets the AngleMaxTolerance parameter.
                |     Role:Return or Set the AngleMaxTolerance parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oAngleMaxTolerance
                |             The angle maximum tolerance value.

        :rtype: float
        """

        return self.tolerance_sheet_setting_att.AngleMaxTolerance

    @angle_max_tolerance.setter
    def angle_max_tolerance(self, value: float):
        """
        :param float value:
        """

        self.tolerance_sheet_setting_att.AngleMaxTolerance = value

    @property
    def angle_min_tolerance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property AngleMinTolerance() As double
                | 
                |     Returns or sets the AngleMinTolerance parameter.
                |     Role:Return or Set the AngleMinTolerance parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oAngleMinTolerance
                |             The angle minimum tolerance value.

        :rtype: float
        """

        return self.tolerance_sheet_setting_att.AngleMinTolerance

    @angle_min_tolerance.setter
    def angle_min_tolerance(self, value: float):
        """
        :param float value:
        """

        self.tolerance_sheet_setting_att.AngleMinTolerance = value

    @property
    def default_tolerance(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property DefaultTolerance() As short
                | 
                |     Returns or sets the DefaultTolerance parameter.
                |     Role:Return or Set the DefaultTolerance parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oDefaultTolerance
                |             Legal values:
                |             0 : to not accept a default tolerance
                |             1 : to accept a default tolerance.

        :rtype: int
        """

        return self.tolerance_sheet_setting_att.DefaultTolerance

    @default_tolerance.setter
    def default_tolerance(self, value: int):
        """
        :param int value:
        """

        self.tolerance_sheet_setting_att.DefaultTolerance = value

    @property
    def length_max_tolerance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property LengthMaxTolerance() As double
                | 
                |     Returns or sets the LengthMaxTolerance parameter.
                |     Role:Return or Set the LengthMaxTolerance parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oLengthMaxTolerance
                |             The length maximum tolerance value.

        :rtype: float
        """

        return self.tolerance_sheet_setting_att.LengthMaxTolerance

    @length_max_tolerance.setter
    def length_max_tolerance(self, value: float):
        """
        :param float value:
        """

        self.tolerance_sheet_setting_att.LengthMaxTolerance = value

    @property
    def length_min_tolerance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)
                | o Property LengthMinTolerance() As double
                | 
                |     Returns or sets the LengthMinTolerance parameter.
                |     Role:Return or Set the LengthMinTolerance parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         oLengthMinTolerance
                |             The length minimum tolerance value.

        :rtype: float
        """

        return self.tolerance_sheet_setting_att.LengthMinTolerance

    @length_min_tolerance.setter
    def length_min_tolerance(self, value: float):
        """
        :param float value:
        """

        self.tolerance_sheet_setting_att.LengthMinTolerance = value

    def get_angle_max_tolerance_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetAngleMaxToleranceInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AngleMaxTolerance
                |     parameter.
                |     Role:Retrieves the state of the AngleMaxTolerance parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tolerance_sheet_setting_att.GetAngleMaxToleranceInfo(io_admin_level, io_locked)

    def get_angle_min_tolerance_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetAngleMinToleranceInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the AngleMinTolerance
                |     parameter.
                |     Role:Retrieves the state of the AngleMinTolerance parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tolerance_sheet_setting_att.GetAngleMinToleranceInfo(io_admin_level, io_locked)

    def get_default_tolerance_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetDefaultToleranceInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DefaultTolerance
                |     parameter.
                |     Role:Retrieves the state of the DefaultTolerance parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tolerance_sheet_setting_att.GetDefaultToleranceInfo(io_admin_level, io_locked)

    def get_length_max_tolerance_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetLengthMaxToleranceInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the LengthMaxTolerance
                |     parameter.
                |     Role:Retrieves the state of the LengthMaxTolerance parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tolerance_sheet_setting_att.GetLengthMaxToleranceInfo(io_admin_level, io_locked)

    def get_length_min_tolerance_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Func GetLengthMinToleranceInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the LengthMinTolerance
                |     parameter.
                |     Role:Retrieves the state of the LengthMinTolerance parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.tolerance_sheet_setting_att.GetLengthMinToleranceInfo(io_admin_level, io_locked)

    def set_angle_max_tolerance_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetAngleMaxToleranceLock(boolean iLocked)
                | 
                |     Locks or unlocks the AngleMaxTolerance parameter.
                |     Role:Locks or unlocks the AngleMaxTolerance parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tolerance_sheet_setting_att.SetAngleMaxToleranceLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_angle_max_tolerance_lock'
        # # vba_code = """
        # # Public Function set_angle_max_tolerance_lock(tolerance_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     tolerance_sheet_setting_att.SetAngleMaxToleranceLock iLocked
        # #     set_angle_max_tolerance_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_angle_min_tolerance_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetAngleMinToleranceLock(boolean iLocked)
                | 
                |     Locks or unlocks the AngleMinTolerance parameter.
                |     Role:Locks or unlocks the AngleMinTolerance parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tolerance_sheet_setting_att.SetAngleMinToleranceLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_angle_min_tolerance_lock'
        # # vba_code = """
        # # Public Function set_angle_min_tolerance_lock(tolerance_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     tolerance_sheet_setting_att.SetAngleMinToleranceLock iLocked
        # #     set_angle_min_tolerance_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_default_tolerance_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetDefaultToleranceLock(boolean iLocked)
                | 
                |     Locks or unlocks the DefaultTolerance parameter.
                |     Role:Locks or unlocks the DefaultTolerance parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tolerance_sheet_setting_att.SetDefaultToleranceLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_default_tolerance_lock'
        # # vba_code = """
        # # Public Function set_default_tolerance_lock(tolerance_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     tolerance_sheet_setting_att.SetDefaultToleranceLock iLocked
        # #     set_default_tolerance_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_length_max_tolerance_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetLengthMaxToleranceLock(boolean iLocked)
                | 
                |     Locks or unlocks the LengthMaxTolerance parameter.
                |     Role:Locks or unlocks the LengthMaxTolerance parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tolerance_sheet_setting_att.SetLengthMaxToleranceLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_length_max_tolerance_lock'
        # # vba_code = """
        # # Public Function set_length_max_tolerance_lock(tolerance_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     tolerance_sheet_setting_att.SetLengthMaxToleranceLock iLocked
        # #     set_length_max_tolerance_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_length_min_tolerance_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))
                | o Sub SetLengthMinToleranceLock(boolean iLocked)
                | 
                |     Locks or unlocks the LengthMinTolerance parameter.
                |     Role:Locks or unlocks the LengthMinTolerance parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.tolerance_sheet_setting_att.SetLengthMinToleranceLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_length_min_tolerance_lock'
        # # vba_code = """
        # # Public Function set_length_min_tolerance_lock(tolerance_sheet_setting_att)
        # #     Dim iLocked (2)
        # #     tolerance_sheet_setting_att.SetLengthMinToleranceLock iLocked
        # #     set_length_min_tolerance_lock = iLocked
        # # End Function
        # # """

        # # system_service = self.application.system_service
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ToleranceSheetSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.any_object import AnyObject


class StrComputeServices(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     StrComputeServices
                | 
                | Represents a structure service object.
                | Structure service object extracts properties on structure objects. Methods of
                | this interface are computing the mass properties of the main body (PartBody) of
                | each Structure Object (Member and Plate)
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.str_compute_services = com_object

    def get_center_of_gravity(self, i_product: Product, o_x: float, o_y: float, o_z: float) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub GetCenterOfGravity(Product iProduct,
                | double oX,
                | double oY,
                | double oZ)
                | 
                |     Retreive the center of gravity for a structure object.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The selected structure object 
                |         oX
                |             The x coordinate of the center of gravity 
                |         oY
                |             The y coordinate of the center of gravity 
                |         oZ
                |             The z coordinate of the center of gravity

        :param Product i_product:
        :param float o_x:
        :param float o_y:
        :param float o_z:
        :rtype: None
        """
        return self.str_compute_services.GetCenterOfGravity(i_product.com_object, o_x, o_y, o_z)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'get_center_of_gravity'
        # # vba_code = """
        # # Public Function get_center_of_gravity(str_compute_services)
        # #     Dim iProduct (2)
        # #     str_compute_services.GetCenterOfGravity iProduct
        # #     get_center_of_gravity = iProduct
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_length(self, i_product: Product) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLength(Product iProduct) As double
                | 
                |     Returns the length to cut for a member object.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The selected structure object

        :param Product i_product:
        :rtype: float
        """
        return self.str_compute_services.GetLength(i_product.com_object)

    def get_mass(self, i_product: Product) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMass(Product iProduct) As double
                | 
                |     Returns the mass for a structure object.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The selected structure object

        :param Product i_product:
        :rtype: float
        """
        return self.str_compute_services.GetMass(i_product.com_object)

    def get_material_name(self, i_product: Product) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMaterialName(Product iProduct) As CATBSTR
                | 
                |     Returns the material name for a structure object.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The selected structure object 
                |         oName
                |             The name of the material

        :param Product i_product:
        :rtype: str
        """
        return self.str_compute_services.GetMaterialName(i_product.com_object)

    def get_surface(self, i_product: Product) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSurface(Product iProduct) As double
                | 
                |     Returns the surface for a structure object.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The selected structure object

        :param Product i_product:
        :rtype: float
        """
        return self.str_compute_services.GetSurface(i_product.com_object)

    def get_volume(self, i_product: Product) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVolume(Product iProduct) As double
                | 
                |     Returns the volume for a structure object.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The selected structure object

        :param Product i_product:
        :rtype: float
        """
        return self.str_compute_services.GetVolume(i_product.com_object)

    def get_wet_area(self, i_product: Product) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetWetArea(Product iProduct) As double
                | 
                |     Returns the wet area for a structure object.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The selected structure object

        :param Product i_product:
        :rtype: float
        """
        return self.str_compute_services.GetWetArea(i_product.com_object)

    def __repr__(self):
        return f'StrComputeServices(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class SWKErgoPushPull(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SWKErgoPushPull
                | 
                | This interface deals the push/pull ergonomic analysis.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.swk_ergo_push_pull = com_object

    @property
    def distance_of_pull(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DistanceOfPull() As CATBSTR
                | 
                |     Returns or sets the distance of pull.
                |     This distance must specified at least once.
                |     Failure to do so will result in invalid output values.

        :rtype: str
        """

        return self.swk_ergo_push_pull.DistanceOfPull

    @distance_of_pull.setter
    def distance_of_pull(self, value: str):
        """
        :param str value:
        """

        self.swk_ergo_push_pull.DistanceOfPull = value

    @property
    def distance_of_push(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DistanceOfPush() As CATBSTR
                | 
                |     Returns or sets the distance of push.
                |     This distance must specified at least once.
                |     Failure to do so will result in invalid output values.

        :rtype: str
        """

        return self.swk_ergo_push_pull.DistanceOfPush

    @distance_of_push.setter
    def distance_of_push(self, value: str):
        """
        :param str value:
        """

        self.swk_ergo_push_pull.DistanceOfPush = value

    @property
    def frequency(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Frequency() As double
                | 
                |     Returns or sets the push/pull frequecy.
                |     This frequency must be expressed in pushes or pulls per second, and
                |     must be specified before attempting to retrive any output value from
                |     the study.
                |     Failure to do so will result in invalid output values.

        :rtype: float
        """

        return self.swk_ergo_push_pull.Frequency

    @frequency.setter
    def frequency(self, value: float):
        """
        :param float value:
        """

        self.swk_ergo_push_pull.Frequency = value

    @property
    def max_initial_pull_force(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxInitialPullForce() As CATBSTR (Read Only)
                | 
                |     This field is the maximum initial pulling force, produced by the study,
                |     given the current input guidelines.

        :rtype: str
        """

        return self.swk_ergo_push_pull.MaxInitialPullForce

    @property
    def max_initial_push_force(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxInitialPushForce() As CATBSTR (Read Only)
                | 
                |     This field is the maximum initial pushing force, produced by the study,
                |     given the current input guidelines.

        :rtype: str
        """

        return self.swk_ergo_push_pull.MaxInitialPushForce

    @property
    def max_sustained_pull_force(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxSustainedPullForce() As CATBSTR (Read Only)
                | 
                |     This field is the maximum sustained pulling force, produced by the study,
                |     given the current input guidelines.

        :rtype: str
        """

        return self.swk_ergo_push_pull.MaxSustainedPullForce

    @property
    def max_sustained_push_force(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property MaxSustainedPushForce() As CATBSTR (Read Only)
                | 
                |     This field is the maximum sustained pushing force, produced by the study,
                |     given the current input guidelines.

        :rtype: str
        """

        return self.swk_ergo_push_pull.MaxSustainedPushForce

    @property
    def population(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Population() As double
                | 
                |     Returns or sets the percentage of the population that should be able to
                |     perform the push/pull task safely.
                |     This property can only take the values 50.0, 75.0 and 90.0, and must be
                |     specified at least once.
                |     Failure to do so will result in invalid output values.

        :rtype: float
        """

        return self.swk_ergo_push_pull.Population

    @population.setter
    def population(self, value: float):
        """
        :param float value:
        """

        self.swk_ergo_push_pull.Population = value

    def __repr__(self):
        return f'SWKErgoPushPull(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class PPRProducts(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     PPRProducts
                | 
                | This interface is used to retrieve and add Products from and to the list of
                | Products.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.ppr_products = com_object

    def add(self, i_product: Product) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(Product iProduct) As Product
                | 
                |     Adds the specified Product to the current list of
                |     Products.
                | 
                |     Parameters:
                | 
                |         iProduct
                |             The Product to be added. 
                | 
                |     Returns:
                |         The added Product.

        :param Product i_product:
        :rtype: Product
        """
        return Product(self.ppr_products.Add(i_product.com_object))

    def item(self, i_index: cat_variant) -> Product:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As Product
                | 
                |     Retrieves the Product corresponding to the specified index in the list of
                |     Products.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index in the Product list. 
                | 
                |     Returns:
                |         The retrieved Product corresponding to the specified index.

        :param cat_variant i_index:
        :rtype: Product
        """
        return Product(self.ppr_products.Item(i_index))

    def __repr__(self):
        return f'PprProducts(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.any_object import AnyObject


class IpdTemplateProperty(AnyObject):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     IPDTemplateProperty
                | 
                | Interface to access template object (being pointed by the given V5 object)
                | properties.
                | Role: This interface given a V5 object, will get the handle to the template
                | object using the pointer attribute referring in it and allows to access the
                | properties of the template object.
                | 
                | This interface expect caller to use attribute name define in PPPR server for
                | example caller should use "note" to access Description .
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.ipd_template_property = com_object

    def get_template_boolean_attribute(self, i_attr_name: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTemplateBooleanAttribute(CATBSTR iAttrName) As
                | boolean
                | 
                |     This gets a String Attribute value of an input Object
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The name of the Attribute whose value we need 
                |         oAttrValue
                |             The value of the attribute 
                | 
                |     Returns:
                |         S_OK

        :param str i_attr_name:
        :rtype: bool
        """
        return self.ipd_template_property.GetTemplateBooleanAttribute(i_attr_name)

    def get_template_double_attribute(self, i_attr_name: str) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTemplateDoubleAttribute(CATBSTR iAttrName) As
                | double
                | 
                |     This gets a String Attribute value of an input Object
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The name of the Attribute whose value we need 
                |         oAttrValue
                |             The value of the attribute 
                | 
                |     Returns:
                |         S_OK

        :param str i_attr_name:
        :rtype: float
        """
        return self.ipd_template_property.GetTemplateDoubleAttribute(i_attr_name)

    def get_template_long_attribute(self, i_attr_name: str) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTemplateLongAttribute(CATBSTR iAttrName) As long
                | 
                |     This gets a String Attribute value of an input Object
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The name of the Attribute whose value we need 
                |         oAttrValue
                |             The value of the attribute 
                | 
                |     Returns:
                |         S_OK

        :param str i_attr_name:
        :rtype: int
        """
        return self.ipd_template_property.GetTemplateLongAttribute(i_attr_name)

    def get_template_string_attribute(self, i_attr_name: str) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetTemplateStringAttribute(CATBSTR iAttrName) As
                | CATBSTR
                | 
                |     This gets a String Attribute value of an input Object
                | 
                |     Parameters:
                | 
                |         iAttrName
                |             The name of the Attribute whose value we need 
                |         oAttrValue
                |             The value of the attribute 
                | 
                |     Returns:
                |         S_OK

        :param str i_attr_name:
        :rtype: str
        """
        return self.ipd_template_property.GetTemplateStringAttribute(i_attr_name)

    def __repr__(self):
        return f'IpdTemplateProperty(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class HtsGeneralSettingAtt(SettingController):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         HtsGeneralSettingAtt

    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hts_general_setting_att = com_object

    @property
    def coll_walk_clearance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CollWalkClearance() As double

        :rtype: float
        """

        return self.hts_general_setting_att.CollWalkClearance

    @coll_walk_clearance.setter
    def coll_walk_clearance(self, value: float):
        """
        :param float value:
        """

        self.hts_general_setting_att.CollWalkClearance = value

    @property
    def collision_search_intensity(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property CollisionSearchIntensity() As short

        :rtype: int
        """

        return self.hts_general_setting_att.CollisionSearchIntensity

    @collision_search_intensity.setter
    def collision_search_intensity(self, value: int):
        """
        :param int value:
        """

        self.hts_general_setting_att.CollisionSearchIntensity = value

    @property
    def constraints_simul(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConstraintsSimul() As short
                | 
                |     Returns or sets the ConstraintsSimul parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_general_setting_att.ConstraintsSimul

    @constraints_simul.setter
    def constraints_simul(self, value: int):
        """
        :param int value:
        """

        self.hts_general_setting_att.ConstraintsSimul = value

    @property
    def default_walk_speed(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property DefaultWalkSpeed() As double
                | 
                |     Returns or sets the DefaultWalkSpeed parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: float
        """

        return self.hts_general_setting_att.DefaultWalkSpeed

    @default_walk_speed.setter
    def default_walk_speed(self, value: float):
        """
        :param float value:
        """

        self.hts_general_setting_att.DefaultWalkSpeed = value

    @property
    def side_step_angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SideStepAngle() As double
                | 
                |     Returns or sets the SideStepAngle parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: float
        """

        return self.hts_general_setting_att.SideStepAngle

    @side_step_angle.setter
    def side_step_angle(self, value: float):
        """
        :param float value:
        """

        self.hts_general_setting_att.SideStepAngle = value

    @property
    def sync_time_and_speed_in_simulation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property SyncTimeAndSpeedInSimulation() As short
                | 
                |     Returns or sets the SyncTimeAndSpeed parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_general_setting_att.SyncTimeAndSpeedInSimulation

    @sync_time_and_speed_in_simulation.setter
    def sync_time_and_speed_in_simulation(self, value: int):
        """
        :param int value:
        """

        self.hts_general_setting_att.SyncTimeAndSpeedInSimulation = value

    @property
    def update_analysis_in_simulation(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UpdateAnalysisInSimulation() As short
                | 
                |     Returns or sets the UpdateAnalysisInSimulation parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_general_setting_att.UpdateAnalysisInSimulation

    @update_analysis_in_simulation.setter
    def update_analysis_in_simulation(self, value: int):
        """
        :param int value:
        """

        self.hts_general_setting_att.UpdateAnalysisInSimulation = value

    @property
    def user_walk_speed_status(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property UserWalkSpeedStatus() As short
                | 
                |     Returns or sets the UserWalkSpeedStatus parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: int
        """

        return self.hts_general_setting_att.UserWalkSpeedStatus

    @user_walk_speed_status.setter
    def user_walk_speed_status(self, value: int):
        """
        :param int value:
        """

        self.hts_general_setting_att.UserWalkSpeedStatus = value

    @property
    def walk_forward_angle(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WalkForwardAngle() As double
                | 
                |     Returns or sets the WalkForwardAngle parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: float
        """

        return self.hts_general_setting_att.WalkForwardAngle

    @walk_forward_angle.setter
    def walk_forward_angle(self, value: float):
        """
        :param float value:
        """

        self.hts_general_setting_att.WalkForwardAngle = value

    @property
    def walk_forward_distance(self) -> float:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property WalkForwardDistance() As double
                | 
                |     Returns or sets the WalkForwardDistance parameter.
                | 
                |     Ensure consistency with the C++ interface to which the work is delegated.

        :rtype: float
        """

        return self.hts_general_setting_att.WalkForwardDistance

    @walk_forward_distance.setter
    def walk_forward_distance(self, value: float):
        """
        :param float value:
        """

        self.hts_general_setting_att.WalkForwardDistance = value

    def get_coll_walk_clearance_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCollWalkClearanceInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_general_setting_att.GetCollWalkClearanceInfo(io_admin_level, io_locked)

    def get_collision_search_intensity_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetCollisionSearchIntensityInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_general_setting_att.GetCollisionSearchIntensityInfo(io_admin_level, io_locked)

    def get_constraints_simul_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetConstraintsSimulInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the ConstraintsSimul
                |     parameter.
                |     Role:Retrieves the state of the ConstraintsSimul parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_general_setting_att.GetConstraintsSimulInfo(io_admin_level, io_locked)

    def get_default_walk_speed_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetDefaultWalkSpeedInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the DefaultWalkSpeed
                |     parameter.
                |     Role:Retrieves the state of the DefaultWalkSpeed parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_general_setting_att.GetDefaultWalkSpeedInfo(io_admin_level, io_locked)

    def get_side_step_angle_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSideStepAngleInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SideStepAngle
                |     parameter.
                |     Role:Retrieves the state of the SideStepAngle parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_general_setting_att.GetSideStepAngleInfo(io_admin_level, io_locked)

    def get_sync_time_and_speed_in_simulation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSyncTimeAndSpeedInSimulationInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SyncTimeAndSpeed
                |     parameter.
                |     Role:Retrieves the state of the SyncTimeAndSpeed parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_general_setting_att.GetSyncTimeAndSpeedInSimulationInfo(io_admin_level, io_locked)

    def get_update_analysis_in_simulation_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUpdateAnalysisInSimulationInfo(CATBSTR
                | ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the UpdateAnalysisInSimulation
                |     parameter.
                |     Role:Retrieves the state of the UpdateAnalysisInSimulation parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_general_setting_att.GetUpdateAnalysisInSimulationInfo(io_admin_level, io_locked)

    def get_user_walk_speed_status_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetUserWalkSpeedStatusInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the UserWalkSpeedStatus
                |     parameter.
                |     Role:Retrieves the state of the UserWalkSpeedStatus parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_general_setting_att.GetUserWalkSpeedStatusInfo(io_admin_level, io_locked)

    def get_walk_forward_angle_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetWalkForwardAngleInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the WalkForwardAngle
                |     parameter.
                |     Role:Retrieves the state of the WalkForwardAngle parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_general_setting_att.GetWalkForwardAngleInfo(io_admin_level, io_locked)

    def get_walk_forward_distance_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetWalkForwardDistanceInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the WalkForwardDistance
                |     parameter.
                |     Role:Retrieves the state of the WalkForwardDistance parameter in the
                |     current environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.hts_general_setting_att.GetWalkForwardDistanceInfo(io_admin_level, io_locked)

    def set_coll_walk_clearance_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCollWalkClearanceLock(boolean iLocked)

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_general_setting_att.SetCollWalkClearanceLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_coll_walk_clearance_lock'
        # # vba_code = """
        # # Public Function set_coll_walk_clearance_lock(hts_general_setting_att)
        # #     Dim iLocked (2)
        # #     hts_general_setting_att.SetCollWalkClearanceLock iLocked
        # #     set_coll_walk_clearance_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_collision_search_intensity_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetCollisionSearchIntensityLock(boolean iLocked)

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_general_setting_att.SetCollisionSearchIntensityLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_collision_search_intensity_lock'
        # # vba_code = """
        # # Public Function set_collision_search_intensity_lock(hts_general_setting_att)
        # #     Dim iLocked (2)
        # #     hts_general_setting_att.SetCollisionSearchIntensityLock iLocked
        # #     set_collision_search_intensity_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_constraints_simul_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetConstraintsSimulLock(boolean iLocked)
                | 
                |     Locks or unlocks the ConstraintsSimul parameter.
                |     Role:Locks or unlocks the ConstraintsSimul parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_general_setting_att.SetConstraintsSimulLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_constraints_simul_lock'
        # # vba_code = """
        # # Public Function set_constraints_simul_lock(hts_general_setting_att)
        # #     Dim iLocked (2)
        # #     hts_general_setting_att.SetConstraintsSimulLock iLocked
        # #     set_constraints_simul_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_default_walk_speed_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetDefaultWalkSpeedLock(boolean iLocked)
                | 
                |     Locks or unlocks the DefaultWalkSpeed parameter.
                |     Role:Locks or unlocks the DefaultWalkSpeed parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_general_setting_att.SetDefaultWalkSpeedLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_default_walk_speed_lock'
        # # vba_code = """
        # # Public Function set_default_walk_speed_lock(hts_general_setting_att)
        # #     Dim iLocked (2)
        # #     hts_general_setting_att.SetDefaultWalkSpeedLock iLocked
        # #     set_default_walk_speed_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_side_step_angle_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSideStepAngleLock(boolean iLocked)
                | 
                |     Locks or unlocks the SideStepAngle parameter.
                |     Role:Locks or unlocks the SideStepAngle parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_general_setting_att.SetSideStepAngleLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_side_step_angle_lock'
        # # vba_code = """
        # # Public Function set_side_step_angle_lock(hts_general_setting_att)
        # #     Dim iLocked (2)
        # #     hts_general_setting_att.SetSideStepAngleLock iLocked
        # #     set_side_step_angle_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_sync_time_and_speed_in_simulation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSyncTimeAndSpeedInSimulationLock(boolean iLocked)
                | 
                |     Locks or unlocks the SyncTimeAndSpeed parameter.
                |     Role:Locks or unlocks the SyncTimeAndSpeed parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_general_setting_att.SetSyncTimeAndSpeedInSimulationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_sync_time_and_speed_in_simulation_lock'
        # # vba_code = """
        # # Public Function set_sync_time_and_speed_in_simulation_lock(hts_general_setting_att)
        # #     Dim iLocked (2)
        # #     hts_general_setting_att.SetSyncTimeAndSpeedInSimulationLock iLocked
        # #     set_sync_time_and_speed_in_simulation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_update_analysis_in_simulation_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUpdateAnalysisInSimulationLock(boolean iLocked)
                | 
                |     Locks or unlocks the UpdateAnalysisInSimulation parameter.
                |     Role:Locks or unlocks the UpdateAnalysisInSimulation parameter if it is
                |     possible in the current administrative context. In user mode this method will
                |     always return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_general_setting_att.SetUpdateAnalysisInSimulationLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_update_analysis_in_simulation_lock'
        # # vba_code = """
        # # Public Function set_update_analysis_in_simulation_lock(hts_general_setting_att)
        # #     Dim iLocked (2)
        # #     hts_general_setting_att.SetUpdateAnalysisInSimulationLock iLocked
        # #     set_update_analysis_in_simulation_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_user_walk_speed_status_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetUserWalkSpeedStatusLock(boolean iLocked)
                | 
                |     Locks or unlocks the UserWalkSpeedStatus parameter.
                |     Role:Locks or unlocks the UserWalkSpeedStatus parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_general_setting_att.SetUserWalkSpeedStatusLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_user_walk_speed_status_lock'
        # # vba_code = """
        # # Public Function set_user_walk_speed_status_lock(hts_general_setting_att)
        # #     Dim iLocked (2)
        # #     hts_general_setting_att.SetUserWalkSpeedStatusLock iLocked
        # #     set_user_walk_speed_status_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_walk_forward_angle_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetWalkForwardAngleLock(boolean iLocked)
                | 
                |     Locks or unlocks the WalkForwardAngle parameter.
                |     Role:Locks or unlocks the WalkForwardAngle parameter if it is possible in
                |     the current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_general_setting_att.SetWalkForwardAngleLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_walk_forward_angle_lock'
        # # vba_code = """
        # # Public Function set_walk_forward_angle_lock(hts_general_setting_att)
        # #     Dim iLocked (2)
        # #     hts_general_setting_att.SetWalkForwardAngleLock iLocked
        # #     set_walk_forward_angle_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_walk_forward_distance_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetWalkForwardDistanceLock(boolean iLocked)
                | 
                |     Locks or unlocks the WalkForwardDistance parameter.
                |     Role:Locks or unlocks the WalkForwardDistance parameter if it is possible
                |     in the current administrative context. In user mode this method will always
                |     return E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.hts_general_setting_att.SetWalkForwardDistanceLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_walk_forward_distance_lock'
        # # vba_code = """
        # # Public Function set_walk_forward_distance_lock(hts_general_setting_att)
        # #     Dim iLocked (2)
        # #     hts_general_setting_att.SetWalkForwardDistanceLock iLocked
        # #     set_walk_forward_distance_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'HtsGeneralSettingAtt(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_insert import ManufacturingInsert
from pycatia.manufacturing_interfaces.manufacturing_tool import ManufacturingTool
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingToolAssembly2(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingToolAssembly2
                | 
                | Represents the tool assembly.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_tool_assembly2 = com_object

    @property
    def insert(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Insert(ManufacturingInsert iMfgInsert) (Write
                | Only)
                | 
                |     Set the insert of an assembly.
                | 
                |     Parameters:
                | 
                |         iMfgInsert
                |             The insert to set to tool assembly

        :rtype: None
        """

        return None

    @insert.setter
    def insert(self, value: ManufacturingInsert):
        """
        :param ManufacturingInsert value:
        """

        self.manufacturing_tool_assembly2.Insert = value.com_object

    @property
    def tool(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Tool(ManufacturingTool iMfgTool) (Write Only)
                | 
                |     Set the tool of an assembly.
                | 
                |     Parameters:
                | 
                |         iMfgTool
                |             The tool to set to tool assembly

        :rtype: None
        """

        return None

    @tool.setter
    def tool(self, value: ManufacturingTool):
        """
        :param False value:
        """

        self.manufacturing_tool_assembly2.Tool = value.com_object

    def __repr__(self):
        return f'ManufacturingToolAssembly2(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import Iterator

from pycatia.in_interfaces.viewpoint_3d import ViewPoint3D
from pycatia.navigator_interfaces.annotated_view import AnnotatedView
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class AnnotatedViews(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     AnnotatedViews
                | 
                | A collection of AnnotatedView objects.
                | 
                | The method Product.GetTechnologicalObject ("AnnotatedViews") on the root
                | product retrieves this collection.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=AnnotatedView)
        self.annotated_views = com_object

    def add(self) -> AnnotatedView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Add() As AnnotatedView
                | 
                |     Creates an annotated view using the current viewpoint and adds it to the
                |     AnnotatedView collection.
                | 
                |     Returns:
                |         The created AnnotatedView 
                |     Example:
                | 
                |              This example creates a new AnnotatedView in the TheAnnotatedViews
                |              collection.
                |             
                | 
                |             Dim NewAnnotatedView As AnnotatedView
                |             Set NewAnnotatedView = TheAnnotatedViews.Add

        :rtype: AnnotatedView
        """
        return AnnotatedView(self.annotated_views.Add())

    def add_from_viewpoint(self, i_viewpoint: ViewPoint3D) -> AnnotatedView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func AddFromViewpoint(Viewpoint3D iViewpoint) As
                | AnnotatedView
                | 
                |     Creates an annotated view using a given viewpoint and adds it to the
                |     AnnotatedView collection.
                | 
                |     Parameters:
                | 
                |         iViewpoint
                |             The viewpoint. 
                | 
                |     Returns:
                |         The created AnnotatedView 
                |     Example:
                | 
                |              This example creates a new AnnotatedView in the TheAnnotatedViews
                |              collection using a 
                |             AViewpoint viewpoint object.
                |             
                | 
                |             Dim NewAnnotatedView As AnnotatedView
                |             Set NewAnnotatedView = TheAnnotatedViews.AddFromViewpoint(AViewpoint)

        :param ViewPoint3D i_viewpoint:
        :rtype: AnnotatedView
        """
        return AnnotatedView(self.annotated_views.AddFromViewpoint(i_viewpoint.com_object))

    def item(self, i_index: cat_variant) -> AnnotatedView:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Func Item(CATVariant iIndex) As AnnotatedView
                | 
                |     Returns an annotated view using its index or its name from the
                |     AnnotatedViews collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the AnnotatedView to retrieve from the
                |             collection of AnnotatedViews. As a numerics, this index is the rank of the
                |             AnnotatedView in the collection. The index of the first AnnotatedView in the
                |             collection is 1, and the index of the last AnnotatedView is Count. As a string,
                |             it is the name you assigned to the AnnotatedView. 
                | 
                |     Returns:
                |         The retrieved AnnotatedView 
                |     Example:
                | 
                |              This example retrieves in ThisAnnotatedView the ninth
                |              AnnotatedView,
                |             and in ThatAnnotatedView the AnnotatedView named
                |             AnnotatedView3 from the TheAnnotatedViews collection.
                |             
                |             
                | 
                |             Dim ThisAnnotatedView As AnnotatedView
                |             Set ThisAnnotatedView = TheAnnotatedViews.Item(9)
                |             Dim ThatAnnotatedView As AnnotatedView
                |             Set ThatAnnotatedView = TheAnnotatedViews.Item("AnnotatedView3")

        :param cat_variant i_index:
        :rtype: AnnotatedView
        """
        return AnnotatedView(self.annotated_views.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes an annotated view from the AnnotatedViews
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the AnnotatedView to retrieve from he
                |             collection of AnnotatedViews. As a numerics, this index is the rank of the
                |             AnnotatedView in the collection. The index of the first AnnotatedView in the
                |             collection is 1, and the index of the last AnnotatedView is Count. As a string,
                |             it is the name you assigned to the AnnotatedView. 
                | 
                |     Example:
                | 
                |              The following example removes the tenth AnnotatedView and the
                |              AnnotatedView named
                |             AnnotatedView2 from the TheAnnotatedViews
                |             collection.
                |             
                | 
                |             TheAnnotatedViews.Remove(10)
                |             TheAnnotatedViews.Remove("AnnotatedView2")

        :param cat_variant i_index:
        :rtype: None
        """
        return self.annotated_views.Remove(i_index)

    def __getitem__(self, n: int) -> AnnotatedView:
        if (n + 1) > self.count:
            raise StopIteration

        return AnnotatedView(self.annotated_views.Item(n + 1))

    def __iter__(self) -> Iterator[AnnotatedView]:
        for i in range(self.count):
            yield self.child_object(self.com_object.Item(i + 1))

    def __repr__(self):
        return f'AnnotatedViews(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-06-11 12:40:47.360445

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.knowledge_interfaces.length import Length
from pycatia.part_interfaces.surface_based_shape import SurfaceBasedShape


class ThickSurface(SurfaceBasedShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.Shape
                |                         PartInterfaces.SurfaceBasedShape
                |                             ThickSurface
                | 
                | Represents the ThickSurface feature.
                | It thicks surface using an offset element (such as a surface or a skin) and two
                | offset values TopOffset and Botoffset. TopOffset is the offset between the
                | offset element and the top skin of the feature. BotOffset is the offset between
                | the offset element and the bottom skin of the feature.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.thick_surface = com_object

    @property
    def bot_offset(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property BotOffset() As Length (Read Only)
                | 
                |     Returns the value of the bottom offset.
                | 
                |     Example:
                |         The following example returns in botoffset the bottom offset of the
                |         thicksurface firstThickSurface:
                | 
                |          Set botoffset = firstThickSurface.BotOffset

        :rtype: Length
        """

        return Length(self.thick_surface.BotOffset)

    @property
    def offset_side(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property OffsetSide() As long (Read Only)
                | 
                |     Returns the offset direction (defines in regards of the normal direction)
                |     .
                | 
                |     Example:
                |         The following example returns in offsetside the side of the
                |         ThickSurface firstThickSurface:
                | 
                |          Set offsetside = firstThickSurface.OffsetSide

        :rtype: int
        """

        return self.thick_surface.OffsetSide

    @property
    def top_offset(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property TopOffset() As Length (Read Only)
                | 
                |     Returns the value of the top offset.
                | 
                |     Example:
                |         The following example returns in topoffset the top offset of the
                |         ThickSurface firstThickSurface:
                | 
                |          Set topoffset = firstThickSurface.TopOffset

        :rtype: Length
        """

        return Length(self.thick_surface.TopOffset)

    def swap_offset_side(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384))
                | o Sub swap_OffsetSide()
                | 
                |     Swap the side of the offset. 
                | 
                | Example:
                |     The following example changes the side of the ThickSurface
                |     firstThickSurface:
                | 
                |      call firstThickSurface.swap_OffsetSide()
                |      
                | 
                |     Copyright © 1999-2011, Dassault Systèmes. All rights
                |     reserved.

        :rtype: None
        """
        return self.thick_surface.swap_OffsetSide()

    def __repr__(self):
        return f'ThickSurface(name="{ self.name }")'
